@@ -6,28 +6,8 @@ package Net::LDAP::Constant;
 
 use Exporter ();
 
-@ISA       = qw(Exporter);
-
-##
-## Compatability
-##
-
-my $sub;
-foreach $sub (grep /^LDAP_/, keys %{'Net::LDAP::Constant::'}) {
-    my $new;
-    ($new = $sub) =~ s/^LDAP_/ldap/;
-    *{$new} = \&{$sub};
-}
-
-sub export_fail {
-    require Carp;
-    Carp::carp("Depricated use of ldapCONSTANT, use LDAP_CONSTANT")
-	if $^W;
-    ();  
-}
-
-@EXPORT_OK   = ( grep /^(LDAP_|ldap[A-Z])/, keys %{'Net::LDAP::Constant::'} );
-@EXPORT_FAIL = ( grep /^ldap[A-Z]/, keys %{'Net::LDAP::Constant::'} );
+@ISA         = qw(Exporter);
+@EXPORT_OK   = ( grep /^LDAP_/, keys %{'Net::LDAP::Constant::'} );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 ##
@@ -45,7 +25,6 @@ sub LDAP_STRONG_AUTH_NOT_SUPPORTED () { 0x07 }
 sub LDAP_AUTH_METHOD_NOT_SUPPORTED () { 0x07 }
 sub LDAP_STRONG_AUTH_REQUIRED      () { 0x08 }
 sub LDAP_PARTIAL_RESULTS           () { 0x09 }
-
 sub LDAP_REFERRAL                  () { 0x0a } # V3
 sub LDAP_ADMIN_LIMIT_EXCEEDED      () { 0x0b } # V3
 sub LDAP_UNAVAILABLE_CRITICAL_EXT  () { 0x0c } # V3
@@ -73,6 +52,9 @@ sub LDAP_UNAVAILABLE               () { 0x34 }
 sub LDAP_UNWILLING_TO_PERFORM      () { 0x35 }
 sub LDAP_LOOP_DETECT               () { 0x36 }
 
+sub LDAP_SORT_CONTROL_MISSING      () { 0x3C }
+sub LDAP_INDEX_RANGE_ERROR         () { 0x3D }
+
 sub LDAP_NAMING_VIOLATION          () { 0x40 }
 sub LDAP_OBJECT_CLASS_VIOLATION    () { 0x41 }
 sub LDAP_NOT_ALLOWED_ON_NONLEAF    () { 0x42 }
@@ -80,7 +62,6 @@ sub LDAP_NOT_ALLOWED_ON_RDN        () { 0x43 }
 sub LDAP_ALREADY_EXISTS            () { 0x44 }
 sub LDAP_NO_OBJECT_CLASS_MODS      () { 0x45 }
 sub LDAP_RESULTS_TOO_LARGE         () { 0x46 }
-
 sub LDAP_AFFECTS_MULTIPLE_DSAS     () { 0x47 } # V3
 
 sub LDAP_OTHER                     () { 0x50 }
@@ -94,5 +75,27 @@ sub LDAP_FILTER_ERROR              () { 0x57 }
 sub LDAP_USER_CANCELED             () { 0x58 }
 sub LDAP_PARAM_ERROR               () { 0x59 }
 sub LDAP_NO_MEMORY                 () { 0x5a }
+sub LDAP_CONNECT_ERROR 		   () { 0x5b }
+sub LDAP_NOT_SUPPORTED 		   () { 0x5c } # V3
+sub LDAP_CONTROL_NOT_FOUND  	   () {	0x5d } # V3
+sub LDAP_NO_RESULTS_RETURNED 	   () {	0x5e } # V3
+sub LDAP_MORE_RESULTS_TO_RETURN    () {	0x5f } # V3
+sub LDAP_CLIENT_LOOP 		   () {	0x60 } # V3
+sub LDAP_REFERRAL_LIMIT_EXCEEDED   () {	0x61 } # V3
+
+# LDAP Controls
+
+sub LDAP_CONTROL_MANAGEDSAIT       () {	"2.16.840.1.113730.3.4.2"  }
+sub LDAP_CONTROL_SORTREQUEST       () {	"1.2.840.113556.1.4.473"   }
+sub LDAP_CONTROL_SORTRESPONSE      () {	"1.2.840.113556.1.4.474"   }
+sub LDAP_CONTROL_PERSISTENTSEARCH  () {	"2.16.840.1.113730.3.4.3"  }
+sub LDAP_CONTROL_ENTRYCHANGE       () {	"2.16.840.1.113730.3.4.7"  }
+sub LDAP_CONTROL_VLVREQUEST        () { "2.16.840.1.113730.3.4.9"  }
+sub LDAP_CONTROL_VLVRESPONSE       () {	"2.16.840.1.113730.3.4.10" }
+# Password information sent back to client
+sub LDAP_CONTROL_PWEXPIRED         () {	"2.16.840.1.113730.3.4.4"  }
+sub LDAP_CONTROL_PWEXPIRING        () {	"2.16.840.1.113730.3.4.5"  }
+# Client controls we know about
+sub LDAP_CONTROL_REFERRALS         () {	"1.2.840.113556.1.4.616"   }
 
 1;
